from db import create_session
from models import CC, CalendarDay, Attendance, Section, Test, SchoolCourse, Course

session = create_session()
# cc = session.query(CC).first()
# att = session.query(Attendance).first()
# calendar_day = session.query(CalendarDay).first()
# sec = session.query(Section).first()
# test = session.query(Test).first()
school_course = session.query(SchoolCourse)
# course = session.query(Course)
for sc in school_course \
        .filter(SchoolCourse.course.has(Course.name == 'Computer Programming I') & SchoolCourse.course.has(Course.credit_hours == 0.5)) \
        .filter(SchoolCourse.school_id == 704) \
        .filter(SchoolCourse.year_id == 28) \
        .all():
    print(sc.course.name)



from pprint import pformat

from sqlalchemy import (Column, ForeignKeyConstraint, Integer, String)
from sqlalchemy.orm import relationship

from .base import Base


class SectionMeeting(Base):
    __tablename__ = 'section_meeting'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
    )

    dcid = Column(Integer, primary_key=True)
    school_id = Column('schoolid', Integer)
    school = relationship('School')
    year_id = Column('yearid', Integer)
    section_id = Column('sectionid', Integer)
    period_number = Column(Integer)
    cycle_day_letter = Column(String)

    def __repr__(self):
        return 'SectionMeeting: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Column, Date, ForeignKeyConstraint, Integer, String)
from sqlalchemy.orm import relationship

from .base import Base


class Attendance(Base):
    __tablename__ = 'attendance'
    __table_args__ = (
        ForeignKeyConstraint(
            ['ccid'],
            ['cc.id']
        ),
        ForeignKeyConstraint(
            ['studentid'],
            ['students.id']
        ),
        ForeignKeyConstraint(
            ['attendance_codeid'],
            ['attendance_code.id']
        ),
        ForeignKeyConstraint(
            ['periodid'],
            ['period.id']
        ),
    )

    dcid = Column(Integer, primary_key=True)
    cc_id = Column('ccid', Integer)
    cc = relationship('CC')
    student_id = Column('studentid', String)
    student = relationship('Student')
    attendance_code_id = Column('attendance_codeid', Integer)
    code = relationship('AttendanceCode')
    period_id = Column('periodid')
    period = relationship('Period')
    date = Column('att_date', Date)

    def __repr__(self):
        return 'Attendance: ' + pformat(vars(self))



import os

from sqlalchemy import create_engine
from sqlalchemy.engine.url import URL
from sqlalchemy.orm import sessionmaker, Session
from pprint import pprint
from dotenv import load_dotenv, find_dotenv

load_dotenv(find_dotenv(usecwd=True))

def create_session() -> Session:
    connect_str = URL(**{
        'drivername': 'oracle',
        "username": os.environ.get('POWERSCHOOL_USER'),
        "password": os.environ.get('POWERSCHOOL_PASSWORD'),
        "host": os.environ.get('POWERSCHOOL_HOST'),
        "port": os.environ.get('POWERSCHOOL_PORT', '1521'),
        "database": os.environ.get('POWERSCHOOL_DATABASE')
    })
    engine = create_engine(connect_str)
    Session = sessionmaker(bind=engine)
    session = Session()
    return session



from pprint import pformat

from sqlalchemy import (Column, ForeignKeyConstraint, Integer, String)
from sqlalchemy.orm import relationship

from .base import Base


class Section(Base):
    __tablename__ = 'sections'
    __table_args__ = (
        ForeignKeyConstraint(
            ['course_number'],
            ['courses.course_number']
        ),
        ForeignKeyConstraint(
            ['termid', 'schoolid'],
            ['terms.id', 'terms.schoolid']
        ),
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
    )

    dcid = Column(Integer, primary_key=True)
    id = Column(Integer, unique=True)
    course_number = Column(String)
    course = relationship('Course')
    term_id = Column('termid', Integer)
    term = relationship('Term')
    school_id = Column('schoolid', Integer)
    school = relationship('School', viewonly=True)
    teacher_id = Column('teacher', Integer)

    def __repr__(self):
        return 'Section: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Column, Integer, String)
from sqlalchemy.orm import relationship
from .base import Base


class Test(Base):
    __tablename__ = 'test'
    
    id = Column(Integer)
    dcid = Column(Integer, primary_key=True)
    name = Column(String)
    description = Column(String)

    test_scores = relationship('TestScore', back_populates='test')

    def __repr__(self):
        return 'Test: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Column, Float, ForeignKeyConstraint, Integer, String)
from sqlalchemy.orm import relationship

from .base import Base


class Course(Base):
    __tablename__ = 'courses'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
    )

    id = Column(Integer)
    dcid = Column(Integer, primary_key=True)
    name = Column('course_name', String)
    code = Column(String)
    number = Column('course_number', String)
    credit_hours = Column(Float)
    school_id = Column('schoolid', Integer)

    school = relationship('School')
    school_courses = relationship('SchoolCourse')

    def __repr__(self):
        return 'Course: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Column, Date, Float,
                        ForeignKeyConstraint, Integer, String)
from sqlalchemy.orm import relationship
from .base import Base


class Student(Base):
    __tablename__ = 'students'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
        ForeignKeyConstraint(
            ['dcid'],
            ['studentcorefields.studentsdcid']
        )
    )

    dcid = Column(Integer, primary_key=True)
    id = Column(Integer, unique=True)
    lastfirst = Column(String)
    first_name = Column(String)
    middle_name = Column(String)
    last_name = Column(String)
    student_number = Column(Float)
    enroll_status = Column(Integer)
    grade_level = Column(String)
    gender = Column(String)
    state_studentnumber = Column(String(length=32))
    entry_date = Column('entrydate', Date)
    father = Column(String)
    mother = Column(String)
    home_phone = Column(String)
    school_id = Column('schoolid', Integer)
    school = relationship('School')
    date_of_birth = Column('dob', Date)
    core_fields = relationship('StudentCoreField', uselist=False)

    @property
    def full_name(self):
        full_name = ''
        full_name += self.first_name
        if self.middle_name:
            full_name += ' ' + self.middle_name
        full_name += ' ' + self.last_name
        return full_name

    def __repr__(self):
        return 'Student: ' + pformat(vars(self))



from pprint import pformat

from sqlalchemy import (Column, ForeignKeyConstraint, Integer)
from sqlalchemy.orm import relationship

from .base import Base


class SchoolCourse(Base):
    __tablename__ = 'school_course'
    __table_args__ = (
        ForeignKeyConstraint(
            ['schoolid'],
            ['schools.school_number']
        ),
        ForeignKeyConstraint(
            ['courseid'],
            ['courses.id']
        ),
        ForeignKeyConstraint(
            ['schoolid', 'yearid'],
            ['terms.schoolid', 'terms.yearid']
        ),
    )

    # id = Column(Integer, unique=True)
    dcid = Column(Integer, primary_key=True)
    school_id = Column('schoolid', Integer)
    course_id = Column('courseid', Integer)
    year_id = Column('yearid', Integer)
    status = Column('status', Integer)

    term = relationship('Term',
                        primaryjoin="and_(SchoolCourse.year_id==Term.year_id, SchoolCourse.school_id==Term.school_id, Term.is_year==True)",
                        viewonly=True)
    school = relationship('School', viewonly=True)
    course = relationship('Course', back_populates='school_courses')

    def __repr__(self):
        return 'SchoolCourse: ' + pformat(vars(self))
